@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017 Osimis, Belgium
+ * Copyright (C) 2017-2018 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -45,8 +45,7 @@ namespace OrthancPlugins
 
     void AddInternal(const std::string& item);
 
-    void AddInternal(const gdcm::File* file,
-                     const gdcm::DataSet& dicom);
+    void AddInternal(const gdcm::DataSet& dicom);
 
   public:
     DicomResults(OrthancPluginContext* context,
@@ -58,13 +57,12 @@ namespace OrthancPlugins
 
     void Add(const gdcm::File& file)
     {
-      AddInternal(&file, file.GetDataSet());
+      AddInternal(file.GetDataSet());
     }
 
-    void Add(const gdcm::File& file,
-             const gdcm::DataSet& subset)
+    void Add(const gdcm::DataSet& subset)
     {
-      AddInternal(&file, subset);
+      AddInternal(subset);
     }
 
     void AddFromOrthanc(const Json::Value& dicom,
