@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017 Osimis, Belgium
+ * Copyright (C) 2017-2018 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -29,8 +29,8 @@
 #include <set>
 #include <boost/lexical_cast.hpp>
 
-#include "../Orthanc/Core/ChunkedBuffer.h"
-#include "../Orthanc/Core/Toolbox.h"
+#include <Core/ChunkedBuffer.h>
+#include <Core/Toolbox.h>
 
 
 static void AddInstance(std::list<std::string>& target,
@@ -285,7 +285,7 @@ void StowClient(OrthancPluginRestOutput* output,
 
   std::map<std::string, std::string> queryArguments;
   std::map<std::string, std::string> httpHeaders;
-  httpHeaders["Accept"] = "application/json";
+  httpHeaders["Accept"] = "application/dicom+json";
   httpHeaders["Expect"] = "";
   httpHeaders["Content-Type"] = mime;
 
@@ -298,7 +298,7 @@ void StowClient(OrthancPluginRestOutput* output,
   Orthanc::ChunkedBuffer chunks;
   size_t countInstances = 0;
 
-  for (std::list<std::string>::const_iterator it = instances.begin(); it != instances.end(); it++)
+  for (std::list<std::string>::const_iterator it = instances.begin(); it != instances.end(); ++it)
   {
     OrthancPlugins::MemoryBuffer dicom(context);
     if (dicom.RestApiGet("/instances/" + *it + "/file", false))
