@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017 Osimis, Belgium
+ * Copyright (C) 2017-2018 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -22,7 +22,8 @@
 #include "DicomWebServers.h"
 
 #include "Configuration.h"
-#include "../Orthanc/Core/Toolbox.h"
+
+#include <Core/Toolbox.h>
 
 namespace OrthancPlugins
 {
@@ -143,7 +144,6 @@ namespace OrthancPlugins
     assert(!url.empty() && url[url.size() - 1] == '/');
 
     // Remove the leading "/" in the URI if need be
-    std::string tmp;
     if (!uri.empty() &&
         uri[0] == '/')
     {
