@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017 Osimis, Belgium
+ * Copyright (C) 2017-2018 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -29,8 +29,8 @@
 #include "Configuration.h"
 #include "DicomWebServers.h"
 
-#include "../Orthanc/Plugins/Samples/Common/OrthancPluginCppWrapper.h"
-#include "../Orthanc/Core/Toolbox.h"
+#include <Plugins/Samples/Common/OrthancPluginCppWrapper.h>
+#include <Core/Toolbox.h>
 
 #include <gdcmDictEntry.h>
 #include <gdcmDict.h>
@@ -87,6 +87,16 @@ void SwitchStudy(OrthancPluginRestOutput* output,
   }
 }
 
+bool RequestHasKey(const OrthancPluginHttpRequest* request, const char* key)
+{
+  for (uint32_t i = 0; i < request->getCount; i++)
+  {
+    if (strcmp(key, request->getKeys[i]) == 0)
+      return true;
+  }
+  return false;
+}
+
 
 void ListServers(OrthancPluginRestOutput* output,
                  const char* url,
@@ -103,18 +113,39 @@ void ListServers(OrthancPluginRestOutput* output,
     std::list<std::string> servers;
     OrthancPlugins::DicomWebServers::GetInstance().ListServers(servers);
 
-    Json::Value json = Json::arrayValue;
-    for (std::list<std::string>::const_iterator it = servers.begin(); it != servers.end(); ++it)
+    if (RequestHasKey(request, "expand"))
     {
-      json.append(*it);
-    }
+      Json::Value result = Json::objectValue;
+      for (std::list<std::string>::const_iterator it = servers.begin(); it != servers.end(); ++it)
+      {
+        Orthanc::WebServiceParameters server = OrthancPlugins::DicomWebServers::GetInstance().GetServer(*it);
+        Json::Value jsonServer;
+        // only return the minimum information to identify the destination, do not include "security" information like passwords
+        jsonServer["Url"] = server.GetUrl();
+        if (!server.GetUsername().empty())
+        {
+          jsonServer["Username"] = server.GetUsername();
+        }
+        result[*it] = jsonServer;
+      }
 
-    std::string answer = json.toStyledString(); 
-    OrthancPluginAnswerBuffer(context, output, answer.c_str(), answer.size(), "application/json");
+      std::string answer = result.toStyledString();
+      OrthancPluginAnswerBuffer(context, output, answer.c_str(), answer.size(), "application/json");
+    }
+    else // if expand is not present, keep backward compatibility and return an array of server names
+    {
+      Json::Value json = Json::arrayValue;
+      for (std::list<std::string>::const_iterator it = servers.begin(); it != servers.end(); ++it)
+      {
+        json.append(*it);
+      }
+
+      std::string answer = json.toStyledString();
+      OrthancPluginAnswerBuffer(context, output, answer.c_str(), answer.size(), "application/json");
+    }
   }
 }
 
-
 void ListServerOperations(OrthancPluginRestOutput* output,
                           const char* /*url*/,
                           const OrthancPluginHttpRequest* request)
