@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017 Osimis, Belgium
+ * Copyright (C) 2017-2018 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -26,7 +26,8 @@
 #include "Dicom.h"
 #include "DicomResults.h"
 #include "Configuration.h"
-#include "../Orthanc/Core/Toolbox.h"
+
+#include <Core/Toolbox.h>
 
 #include <gdcmTag.h>
 #include <list>
@@ -157,11 +158,11 @@ namespace
 
 
   public:
-    ModuleMatcher(const OrthancPluginHttpRequest* request) :
-    fuzzy_(false),
-    offset_(0),
-    limit_(0),
-    includeAllFields_(false)
+    explicit ModuleMatcher(const OrthancPluginHttpRequest* request) :
+      fuzzy_(false),
+      offset_(0),
+      limit_(0),
+      includeAllFields_(false)
     {
       std::string args;
       
@@ -197,7 +198,7 @@ namespace
         }
         else if (key == "includefield")
         {
-          if (key == "all")
+          if (value == "all")
           {
             includeAllFields_ = true;
           }
@@ -270,18 +271,18 @@ namespace
       }
 
       result["Expand"] = false;
-      result["CaseSensitive"] = true;
+      result["CaseSensitive"] = OrthancPlugins::Configuration::GetBooleanValue("QidoCaseSensitive", true);
       result["Query"] = Json::objectValue;
       result["Limit"] = limit_;
       result["Since"] = offset_;
 
       if (offset_ != 0 &&
           !OrthancPlugins::CheckMinimalOrthancVersion(
-            OrthancPlugins::Configuration::GetContext(), 1, 2, 1))
+            OrthancPlugins::Configuration::GetContext(), 1, 3, 0))
       {
         OrthancPlugins::Configuration::LogError(
           "QIDO-RS request with \"offset\" argument: "
-          "Only available if the Orthanc core version is >= 1.2.1");
+          "Only available if the Orthanc core version is >= 1.3.0");
       }
       
       for (Filters::const_iterator it = filters_.begin(); 
