@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017 Osimis, Belgium
+ * Copyright (C) 2017-2018 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -21,10 +21,11 @@
 
 #include "WadoRs.h"
 
-#include "../Orthanc/Core/Toolbox.h"
 #include "Dicom.h"
 #include "Plugin.h"
 
+#include <Core/Toolbox.h>
+
 #include <memory>
 #include <list>
 #include <gdcmImageReader.h>
